@@ -69,7 +69,7 @@ class Client():
                  port=56000,
                  reconnectable=None,
                  bs=8096,
-                 txes=None,
+                 txbs=None,
                  rxbs=None,
                  wlog=None):
         """
@@ -84,7 +84,7 @@ class Client():
             port = socket port
             reconnectable = Boolean retry auto reconnect if timed out
             bs = buffer size
-            txes = deque of data to send
+            txbs = bytearray of data to send
             rxbs = bytearray of data received
             wlog = WireLog object if any
         """
@@ -107,7 +107,7 @@ class Client():
         self.opened = False
 
         self.bs = bs
-        self.txes = txes if txes is not None else deque()  # deque of data to send
+        self.txbs = txbs if txbs is not None else bytearray()  # byte array of data to send
         self.rxbs = rxbs if rxbs is not None else bytearray()  # byte array of data recieved
         self.wlog = wlog
 
@@ -430,11 +430,11 @@ class Client():
         data is string in python2 and bytes in python3
         """
         try:
-            result = self.cs.send(data) #result is number of bytes sent
+            count = self.cs.send(data)  # result is number of bytes sent
         except socket.error as ex:
             # ex.args[0] is always ex.errno for better compat
             if ex.args[0] in (errno.EAGAIN, errno.EWOULDBLOCK):
-                result = 0  # blocked try again
+                count = 0  # blocked try again
             elif ex.args[0] in (errno.ECONNRESET,
                                 errno.ENETRESET,
                                 errno.ENETUNREACH,
@@ -445,45 +445,43 @@ class Client():
                                 errno.ECONNREFUSED):
 
                 self.cutoff = True  # this signals need to close/reopen connection
-                result = 0
+                count = 0
             else:
                 raise
 
-        if result:
+        if count:
             if self.wlog:
-                self.wlog.writeTx(self.ha, data[:result])
+                self.wlog.writeTx(self.ha, data[:count])
 
-        return result
+        return count
 
 
     def tx(self, data):
         '''
-        Queue data onto .txes
+        Queue data onto .txbs
         '''
-        self.txes.append(data)
+        self.txbs.extend(data)
 
 
-    def serviceTxes(self):
+    def serviceSends(self):
         """
         Service transmits
         For each tx if all bytes sent then keep sending until partial send
         or no more to send
         If partial send reattach and return
         """
-        while self.txes and self.connected and not self.cutoff:
-            data = self.txes.popleft()
-            count = self.send(data)
-            if count < len(data):  # put back unsent portion
-                self.txes.appendleft(data[count:])
-                break  # try again later
+        while self.txbs and self.connected and not self.cutoff:
+            count = self.send(self.txbs)
+            del self.txbs[:count]
+            break  # try again later
 
 
-    def serviceAll(self):
+    def service(self):
         """
-        Service connect, txes, and receives.
+        Service connect, txbs, and receives.
         """
         self.serviceConnect()
-        self.serviceTxes()
+        self.serviceSends()
         self.serviceReceives()
 
 
